==> qt3d-opensource-src_5.5.1.orig.tar.xz: qt3d-opensource-src-5.5.1/src/core/jobs/qaspectjobmanager_p.h <==
/****************************************************************************
**
** Copyright (C) 2014 Klaralvdalens Datakonsult AB (KDAB).
** Contact: http://www.qt-project.org/legal
**
** This file is part of the Qt3D module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL3$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see http://www.qt.io/terms-conditions. For further
** information use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPLv3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or later as published by the Free
** Software Foundation and appearing in the file LICENSE.GPL included in
** the packaging of this file. Please review the following information to
** ensure the GNU General Public License version 2.0 requirements will be
** met: http://www.gnu.org/licenses/gpl-2.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QT3D_QASPECTJOBMANAGER_P_H
#define QT3D_QASPECTJOBMANAGER_P_H

#include <private/qabstractaspectjobmanager_p.h>
#include <Qt3DCore/private/qt3dcore_global_p.h>

#include <Qt3DCore/qaspectjob.h>

#include <QVector>

#ifdef THREAD_WEAVER
namespace ThreadWeaver {
class Queue;
}
#endif

QT_BEGIN_NAMESPACE

namespace Qt3D {

class QThreadPooler;
class DependencyHandler;

class QT3DCORE_PRIVATE_EXPORT QAspectJobManager : public QAbstractAspectJobManager
{
    Q_OBJECT
public:
    explicit QAspectJobManager(QObject *parent = 0);
    ~QAspectJobManager();

    void initialize() Q_DECL_OVERRIDE;

    void enqueueJobs(const QVector<QAspectJobPtr> &jobQueue) Q_DECL_OVERRIDE;

    void waitForAllJobs() Q_DECL_OVERRIDE;

    void waitForPerThreadFunction(JobFunction func, void *arg) Q_DECL_OVERRIDE;

private:
#ifdef THREAD_WEAVER
    // Owned by QAspectJobManager via QObject parent-child
    ThreadWeaver::Queue *m_weaver;
#endif

    QThreadPooler *m_threadPooler;
    QScopedPointer<DependencyHandler> m_dependencyHandler;
};

} // namespace Qt3D

QT_END_NAMESPACE

#endif // QT3D_QASPECTJOBMANAGER_P_H

==> qt3d-opensource-src-5.6.2.tar.xz: qt3d-opensource-src-5.6.2/src/core/jobs/qaspectjobmanager_p.h <==
/****************************************************************************
**
** Copyright (C) 2014 Klaralvdalens Datakonsult AB (KDAB).
** Contact: http://www.qt-project.org/legal
**
** This file is part of the Qt3D module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL3$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see http://www.qt.io/terms-conditions. For further
** information use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPLv3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or later as published by the Free
** Software Foundation and appearing in the file LICENSE.GPL included in
** the packaging of this file. Please review the following information to
** ensure the GNU General Public License version 2.0 requirements will be
** met: http://www.gnu.org/licenses/gpl-2.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#ifndef QT3DCORE_QASPECTJOBMANAGER_P_H
#define QT3DCORE_QASPECTJOBMANAGER_P_H

//
//  W A R N I N G
//  -------------
//
// This file is not part of the Qt API.  It exists for the convenience
// of other Qt classes.  This header file may change from version to
// version without notice, or even be removed.
//
// We mean it.
//

#include <private/qabstractaspectjobmanager_p.h>
#include <Qt3DCore/private/qt3dcore_global_p.h>

#include <Qt3DCore/qaspectjob.h>

#include <QVector>

QT_BEGIN_NAMESPACE

namespace Qt3DCore {

class QThreadPooler;
class DependencyHandler;

class QT3DCORE_PRIVATE_EXPORT QAspectJobManager : public QAbstractAspectJobManager
{
    Q_OBJECT
public:
    explicit QAspectJobManager(QObject *parent = 0);
    ~QAspectJobManager();

    void initialize() Q_DECL_OVERRIDE;

    void enqueueJobs(const QVector<QAspectJobPtr> &jobQueue) Q_DECL_OVERRIDE;

    void waitForAllJobs() Q_DECL_OVERRIDE;

    void waitForPerThreadFunction(JobFunction func, void *arg) Q_DECL_OVERRIDE;

private:
    QThreadPooler *m_threadPooler;
    QScopedPointer<DependencyHandler> m_dependencyHandler;
};

} // namespace Qt3DCore

QT_END_NAMESPACE

#endif // QT3DCORE_QASPECTJOBMANAGER_P_H
